#! /bin/sh 
##
## ::DOCCO::
## Little transformer script for demonstration purposes.
## Uses Saxon's XSLT engine for the XSLT2 processor needs.
## This script is NOT flexible enough to handle other
## XSLT2 engines with incompatible calling convention.
## 
## environment:
## - A
## - B
##
## options:
##  NONE!
##
## sample usage:
## env SAXON=/usr/local/lib/saxon9.jar sh ./transform.sh
##
## ::DOCCO::
## -- Martin S. Weber (@NIST) || Nov/16/2009 --
##

if [ -z "$JAVA" ] ; then 
	# $JAVA is unset or empty
	if type java | grep -q 'java is '; then
		JAVA=$(type java | sed -e 's,java is ,,')
		export JAVA
	else
		echo "ERROR: Could not find an executable java vm." 1>&2
		echo "       Either put java in your PATH or set the" 1>&2
		echo "       JAVA environment variable to point to the vm." 1>&2
		exit 1
	fi
else
	# $JAVA is set and non-empty
	if ! [ -x $JAVA ]; then 
		echo "ERROR: \$JAVA $JAVA is not readable & executable!" 1>&2
		exit 1
	fi
	if ${JAVA} -version > /dev/null 2>&1 ; then
		# $JAVA supports a -version option
		if ! ${JAVA} -version 2>&1 | grep -q "java version" ; then 
			# $JAVA formats the version string strange?
			echo "WARNING: Are you certain, that \$JAVA $JAVA" 1>&2
			echo "         is actually a java vm/Runtime?" 1>&2
			echo "         It claims it is:" 1>&2
			echo "$(${JAVA} -version 2>&1 | sed -e 's,^,          >> ,g')" 1>&2
		else
			# everything fine supposedly
		fi
	else
		# $JAVA doesn't support the '-version' argument??
		echo "ERROR: \$JAVA ${JAVA} seems unacceptable:" 1>&2
		echo "       The JVM needs to accept at least the '-version' option!" 1>&2
		exit 1
	fi
fi

if [ -z "$SAXON" ]; then
	# Hmm, how do we find a saxon jar?
	echo "ERROR: \$SAXON unset!" 1>&2
	exit 1
else
	# $SAXON is set and non-empty
	# a) it should be a *.jar
	if [ "$SAXON" = "${SAXON%.jar}" ]; then
		echo "ERROR: \$SAXON should be pointing to a readable" 1>&2
		echo "       jar file that hopefully contains the saxon" 1>&2
		echo "       xslt2 engine." 1>&2
		echo "       Instead it points to '$SAXON'" 1>&2
		exit 1
	fi
	# b) it should be readable
	if ! [ -r "$SAXON" ]; then
		echo "ERROR: \$SAXON $SAXON is not readable!" 1>&2
		exit 1
	fi
fi

# insanity checks:
if [ -z "$SAXON" -o -z "$JAVA" ] ; then
	echo "ERROR: either \$SAXON or \$JAVA unset?!" 1>&2
	exit 1
fi

# alright. Reaching here we know that we have both a valid
# JAVA as well as SAXON environment variable content. Either
# synthesized or passed by the caller. We should thus be
# able to just use it.

# adjust the java classpath to include the saxon JAR
#
CLASSPATH="${SAXON}":"${CLASSPATH}"
export CLASSPATH

MAIN="net.sf.saxon.Transform"

execute() {
	template=${TMPDIR:-/tmp}/TRANSFORM.SH.XXXXXXXX

	if ! f=$(mktemp $template) > /dev/null 2>&1 ; then
		echo "PANIC: There's something wrong with mktemp??!" 1>&2
		exit 1
	else 
		CMD="$JAVA $MAIN $@"
		echo "Executing '$CMD'" > "$f"
		if ! $CMD >> "$f" 2>&1 ; then 
			echo "ERROR: Hrm, something went wrong here!"
			sed -e 's,^, > ,' < "$f" 1>&2
		fi
		rm -f "$f"
	fi
}

execute -s:time-nv.xml -xsl:convertToTargetUnitSystem.xsl -o:Example1.xml USCDFile=USCD-Example3.xml
execute -s:time-nv.xml -xsl:convertToTargetUnitSystem.xsl -o:Example2.xml USCDFile=USCD-Example2.xml
#execute -s:abstract-nv.xml -xsl:convertToTargetUnitSystem.xsl -o:Example3.xml USCDFile=abstract-nv.xml#AbstractUSCD
